# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from bsg_api.models.alternative_channel import AlternativeChannel
from bsg_api.models.phone import Phone
from typing import Optional, Set
from typing_extensions import Self

class SendViberCampaign(BaseModel):
    """
    SendViberCampaign
    """ # noqa: E501
    phones: Annotated[List[Phone], Field(min_length=1, max_length=5000)] = Field(description="The list of objects containing information about the mobile phone number (number) and (reference_id) to send a message to")
    sender: StrictStr = Field(description="Sender’s name: from 3 to 11 characters for the sender’s alphanumeric name (Latin letters, symbols, numbers, spaces); 3 to 15 characters for the sender’s numeric name. To setup senders visit the [account](https://app.bsg.world/sms/senders)")
    text: Annotated[str, Field(min_length=1, strict=True, max_length=1000)]
    image_url: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    button_caption: Optional[Annotated[str, Field(strict=True, max_length=20)]] = None
    link_url: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Required if button_caption is set")
    start_at: Optional[datetime] = Field(default=None, description="Start sending the messages at")
    tariff_code: Optional[StrictInt] = Field(default=None, description="Tariff code null by default. Your can pass specified one if you have several. For more information please visit the [account prices](https://app.bsg.world/prices/sms)")
    validity: Optional[Annotated[int, Field(le=72, strict=True, ge=1)]] = Field(default=72, description="validity time in hours. The default is 72 hours. Integer from 1 to 72")
    alternative_channel: Optional[AlternativeChannel] = None
    add_to_contact_book: Optional[StrictBool] = Field(default=True, description="Specifies whether to add the specified phone number of the message recipient to the contact book")
    check_stop_list: Optional[StrictBool] = Field(default=True, description="Check the recipient’s phone number for being in the stop list.  Possible values:    - true – if the number is found in the stop list, do not send the message  - false – ignore the stop list")
    __properties: ClassVar[List[str]] = ["phones", "sender", "text", "image_url", "button_caption", "link_url", "start_at", "tariff_code", "validity", "alternative_channel", "add_to_contact_book", "check_stop_list"]

    @field_validator('image_url')
    def image_url_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(http|https):\/\/([A-Z0-9][A-Z0-9_-]*)(\.[A-Z0-9][A-Z0-9_-]*)+(:(\d+))?([-_\/A-Z0-9?=&]*)?(\.jpg|\.png|\.tiff|\.jpeg|\.gif|\.bmp){1}$", value ,re.IGNORECASE):
            raise ValueError(r"must validate the regular expression /^(http|https):\/\/([A-Z0-9][A-Z0-9_-]*)(\.[A-Z0-9][A-Z0-9_-]*)+(:(\d+))?([-_\/A-Z0-9?=&]*)?(\.jpg|\.png|\.tiff|\.jpeg|\.gif|\.bmp){1}$/iD")
        return value

    @field_validator('link_url')
    def link_url_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(https?:\/\/)?([\p{L}\d\.-]+)\.([\p{L}\.]{2,50})([\/\w \.-]*)*\/?", value ,re.IGNORECASE ,re.UNICODE):
            raise ValueError(r"must validate the regular expression /^(https?:\/\/)?([\p{L}\d\.-]+)\.([\p{L}\.]{2,50})([\/\w \.-]*)*\/?/iu")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SendViberCampaign from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in phones (list)
        _items = []
        if self.phones:
            for _item_phones in self.phones:
                if _item_phones:
                    _items.append(_item_phones.to_dict())
            _dict['phones'] = _items
        # override the default output from pydantic by calling `to_dict()` of alternative_channel
        if self.alternative_channel:
            _dict['alternative_channel'] = self.alternative_channel.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SendViberCampaign from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "phones": [Phone.from_dict(_item) for _item in obj["phones"]] if obj.get("phones") is not None else None,
            "sender": obj.get("sender"),
            "text": obj.get("text"),
            "image_url": obj.get("image_url"),
            "button_caption": obj.get("button_caption"),
            "link_url": obj.get("link_url"),
            "start_at": obj.get("start_at"),
            "tariff_code": obj.get("tariff_code"),
            "validity": obj.get("validity") if obj.get("validity") is not None else 72,
            "alternative_channel": AlternativeChannel.from_dict(obj["alternative_channel"]) if obj.get("alternative_channel") is not None else None,
            "add_to_contact_book": obj.get("add_to_contact_book") if obj.get("add_to_contact_book") is not None else True,
            "check_stop_list": obj.get("check_stop_list") if obj.get("check_stop_list") is not None else True
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from bsg_api.models.email_response import EmailResponse
from bsg_api.models.send_email import SendEmail
from bsg_api.models.send_template_email import SendTemplateEmail

from bsg_api.api_client import ApiClient, RequestSerialized
from bsg_api.api_response import ApiResponse
from bsg_api.rest import RESTResponseType


class EmailApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def email_send(
        self,
        send_email: SendEmail,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EmailResponse:
        """Send Email

        Method is designed for sending single email with optional parameters.    This request allows you to send emails with both text and HTML content, and optionally include inline media, such as images or other files, which are embedded directly in the email body for a richer user experience

        :param send_email: (required)
        :type send_email: SendEmail
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._email_send_serialize(
            send_email=send_email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "EmailResponse",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def email_send_with_http_info(
        self,
        send_email: SendEmail,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EmailResponse]:
        """Send Email

        Method is designed for sending single email with optional parameters.    This request allows you to send emails with both text and HTML content, and optionally include inline media, such as images or other files, which are embedded directly in the email body for a richer user experience

        :param send_email: (required)
        :type send_email: SendEmail
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._email_send_serialize(
            send_email=send_email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "EmailResponse",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def email_send_without_preload_content(
        self,
        send_email: SendEmail,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Send Email

        Method is designed for sending single email with optional parameters.    This request allows you to send emails with both text and HTML content, and optionally include inline media, such as images or other files, which are embedded directly in the email body for a richer user experience

        :param send_email: (required)
        :type send_email: SendEmail
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._email_send_serialize(
            send_email=send_email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "EmailResponse",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _email_send_serialize(
        self,
        send_email,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if send_email is not None:
            _body_params = send_email


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/email/send-emails',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def email_template_send(
        self,
        send_template_email: SendTemplateEmail,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EmailResponse:
        """Send Email template

        Method allows you to send an email with dynamic content by referencing an email template (specifying template id). You can customize the content of the email with variables, and you also have the option to embed inline media files

        :param send_template_email: (required)
        :type send_template_email: SendTemplateEmail
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._email_template_send_serialize(
            send_template_email=send_template_email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "EmailResponse",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def email_template_send_with_http_info(
        self,
        send_template_email: SendTemplateEmail,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EmailResponse]:
        """Send Email template

        Method allows you to send an email with dynamic content by referencing an email template (specifying template id). You can customize the content of the email with variables, and you also have the option to embed inline media files

        :param send_template_email: (required)
        :type send_template_email: SendTemplateEmail
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._email_template_send_serialize(
            send_template_email=send_template_email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "EmailResponse",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def email_template_send_without_preload_content(
        self,
        send_template_email: SendTemplateEmail,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Send Email template

        Method allows you to send an email with dynamic content by referencing an email template (specifying template id). You can customize the content of the email with variables, and you also have the option to embed inline media files

        :param send_template_email: (required)
        :type send_template_email: SendTemplateEmail
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._email_template_send_serialize(
            send_template_email=send_template_email,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "EmailResponse",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _email_template_send_serialize(
        self,
        send_template_email,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if send_template_email is not None:
            _body_params = send_template_email


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/email/send-template-emails',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# flake8: noqa

# import apis into api package
from bsg_api.api.account_settings_api import AccountSettingsApi
from bsg_api.api.auth_api import AuthApi
from bsg_api.api.balance_api import BalanceApi
from bsg_api.api.campaign_api import CampaignApi
from bsg_api.api.campaign_rcs_api import CampaignRCSApi
from bsg_api.api.campaign_sms_api import CampaignSMSApi
from bsg_api.api.campaign_viber_api import CampaignViberApi
from bsg_api.api.campaign_whats_app_api import CampaignWhatsAppApi
from bsg_api.api.contact_api import ContactApi
from bsg_api.api.contact_field_api import ContactFieldApi
from bsg_api.api.contact_list_api import ContactListApi
from bsg_api.api.email_api import EmailApi
from bsg_api.api.message_rcs_api import MessageRCSApi
from bsg_api.api.messages_api import MessagesApi
from bsg_api.api.messages_sms_api import MessagesSMSApi
from bsg_api.api.messages_whats_app_api import MessagesWhatsAppApi
from bsg_api.api.senders_api import SendersApi
from bsg_api.api.short_domains_api import ShortDomainsApi
from bsg_api.api.short_links_api import ShortLinksApi
from bsg_api.api.statistic_api import StatisticApi
from bsg_api.api.stop_list_api import StopListApi
from bsg_api.api.two_faotp_api import TwoFAOTPApi
from bsg_api.api.two_fa_templates_api import TwoFATemplatesApi




# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import date
from pydantic import Field, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from bsg_api.models.cancel_otp200_response import CancelOtp200Response
from bsg_api.models.otp_channel import OtpChannel
from bsg_api.models.otp_list200_response import OtpList200Response
from bsg_api.models.otp_status import OtpStatus
from bsg_api.models.resend_otp200_response import ResendOtp200Response
from bsg_api.models.send_otp201_response import SendOtp201Response
from bsg_api.models.send_otp_request import SendOtpRequest
from bsg_api.models.sort_way import SortWay
from bsg_api.models.status_otp200_response import StatusOtp200Response
from bsg_api.models.verify_otp200_response import VerifyOtp200Response
from bsg_api.models.verify_otp_request import VerifyOtpRequest

from bsg_api.api_client import ApiClient, RequestSerialized
from bsg_api.api_response import ApiResponse
from bsg_api.rest import RESTResponseType


class TwoFAOTPApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def cancel_otp(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CancelOtp200Response:
        """Cancel the authentication session

        Used to cancel the authentication process. In this case, authentication must be in the Pending status.

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CancelOtp200Response",
            '404': "CancelOtp404Response",
            '422': "CancelOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def cancel_otp_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CancelOtp200Response]:
        """Cancel the authentication session

        Used to cancel the authentication process. In this case, authentication must be in the Pending status.

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CancelOtp200Response",
            '404': "CancelOtp404Response",
            '422': "CancelOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def cancel_otp_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Cancel the authentication session

        Used to cancel the authentication process. In this case, authentication must be in the Pending status.

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CancelOtp200Response",
            '404': "CancelOtp404Response",
            '422': "CancelOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _cancel_otp_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/2fa/authentications/{id}/cancel',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def otp_list(
        self,
        filter_from: Annotated[date, Field(description="Period start date (date and time when the authentication session was created) in ISO 8601 format.")],
        filter_to: Annotated[date, Field(description="End date of the period (date and time when the authentication was created) in ISO 8601 format.")],
        page_offset: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        page_limit: Optional[Annotated[int, Field(le=500, strict=True, ge=10)]] = None,
        filter_ids: Annotated[Optional[Annotated[List[StrictStr], Field(min_length=1, max_length=3)]], Field(description="Authentication ID. The maximum number is 3.")] = None,
        filter_status: Optional[OtpStatus] = None,
        filter_channel: Optional[OtpChannel] = None,
        filter_recipient: Optional[StrictStr] = None,
        filter_country_code: Optional[StrictStr] = None,
        way: Optional[SortWay] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Sort by")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OtpList200Response:
        """List of authentication sessions

        Use to get a list of authentications for a period.

        :param filter_from: Period start date (date and time when the authentication session was created) in ISO 8601 format. (required)
        :type filter_from: date
        :param filter_to: End date of the period (date and time when the authentication was created) in ISO 8601 format. (required)
        :type filter_to: date
        :param page_offset:
        :type page_offset: int
        :param page_limit:
        :type page_limit: int
        :param filter_ids: Authentication ID. The maximum number is 3.
        :type filter_ids: List[str]
        :param filter_status:
        :type filter_status: OtpStatus
        :param filter_channel:
        :type filter_channel: OtpChannel
        :param filter_recipient:
        :type filter_recipient: str
        :param filter_country_code:
        :type filter_country_code: str
        :param way:
        :type way: SortWay
        :param sort: Sort by
        :type sort: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._otp_list_serialize(
            filter_from=filter_from,
            filter_to=filter_to,
            page_offset=page_offset,
            page_limit=page_limit,
            filter_ids=filter_ids,
            filter_status=filter_status,
            filter_channel=filter_channel,
            filter_recipient=filter_recipient,
            filter_country_code=filter_country_code,
            way=way,
            sort=sort,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OtpList200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def otp_list_with_http_info(
        self,
        filter_from: Annotated[date, Field(description="Period start date (date and time when the authentication session was created) in ISO 8601 format.")],
        filter_to: Annotated[date, Field(description="End date of the period (date and time when the authentication was created) in ISO 8601 format.")],
        page_offset: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        page_limit: Optional[Annotated[int, Field(le=500, strict=True, ge=10)]] = None,
        filter_ids: Annotated[Optional[Annotated[List[StrictStr], Field(min_length=1, max_length=3)]], Field(description="Authentication ID. The maximum number is 3.")] = None,
        filter_status: Optional[OtpStatus] = None,
        filter_channel: Optional[OtpChannel] = None,
        filter_recipient: Optional[StrictStr] = None,
        filter_country_code: Optional[StrictStr] = None,
        way: Optional[SortWay] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Sort by")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OtpList200Response]:
        """List of authentication sessions

        Use to get a list of authentications for a period.

        :param filter_from: Period start date (date and time when the authentication session was created) in ISO 8601 format. (required)
        :type filter_from: date
        :param filter_to: End date of the period (date and time when the authentication was created) in ISO 8601 format. (required)
        :type filter_to: date
        :param page_offset:
        :type page_offset: int
        :param page_limit:
        :type page_limit: int
        :param filter_ids: Authentication ID. The maximum number is 3.
        :type filter_ids: List[str]
        :param filter_status:
        :type filter_status: OtpStatus
        :param filter_channel:
        :type filter_channel: OtpChannel
        :param filter_recipient:
        :type filter_recipient: str
        :param filter_country_code:
        :type filter_country_code: str
        :param way:
        :type way: SortWay
        :param sort: Sort by
        :type sort: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._otp_list_serialize(
            filter_from=filter_from,
            filter_to=filter_to,
            page_offset=page_offset,
            page_limit=page_limit,
            filter_ids=filter_ids,
            filter_status=filter_status,
            filter_channel=filter_channel,
            filter_recipient=filter_recipient,
            filter_country_code=filter_country_code,
            way=way,
            sort=sort,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OtpList200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def otp_list_without_preload_content(
        self,
        filter_from: Annotated[date, Field(description="Period start date (date and time when the authentication session was created) in ISO 8601 format.")],
        filter_to: Annotated[date, Field(description="End date of the period (date and time when the authentication was created) in ISO 8601 format.")],
        page_offset: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        page_limit: Optional[Annotated[int, Field(le=500, strict=True, ge=10)]] = None,
        filter_ids: Annotated[Optional[Annotated[List[StrictStr], Field(min_length=1, max_length=3)]], Field(description="Authentication ID. The maximum number is 3.")] = None,
        filter_status: Optional[OtpStatus] = None,
        filter_channel: Optional[OtpChannel] = None,
        filter_recipient: Optional[StrictStr] = None,
        filter_country_code: Optional[StrictStr] = None,
        way: Optional[SortWay] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Sort by")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List of authentication sessions

        Use to get a list of authentications for a period.

        :param filter_from: Period start date (date and time when the authentication session was created) in ISO 8601 format. (required)
        :type filter_from: date
        :param filter_to: End date of the period (date and time when the authentication was created) in ISO 8601 format. (required)
        :type filter_to: date
        :param page_offset:
        :type page_offset: int
        :param page_limit:
        :type page_limit: int
        :param filter_ids: Authentication ID. The maximum number is 3.
        :type filter_ids: List[str]
        :param filter_status:
        :type filter_status: OtpStatus
        :param filter_channel:
        :type filter_channel: OtpChannel
        :param filter_recipient:
        :type filter_recipient: str
        :param filter_country_code:
        :type filter_country_code: str
        :param way:
        :type way: SortWay
        :param sort: Sort by
        :type sort: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._otp_list_serialize(
            filter_from=filter_from,
            filter_to=filter_to,
            page_offset=page_offset,
            page_limit=page_limit,
            filter_ids=filter_ids,
            filter_status=filter_status,
            filter_channel=filter_channel,
            filter_recipient=filter_recipient,
            filter_country_code=filter_country_code,
            way=way,
            sort=sort,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OtpList200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _otp_list_serialize(
        self,
        filter_from,
        filter_to,
        page_offset,
        page_limit,
        filter_ids,
        filter_status,
        filter_channel,
        filter_recipient,
        filter_country_code,
        way,
        sort,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'filter[ids]': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page_offset is not None:
            
            _query_params.append(('page[offset]', page_offset))
            
        if page_limit is not None:
            
            _query_params.append(('page[limit]', page_limit))
            
        if filter_from is not None:
            if isinstance(filter_from, date):
                _query_params.append(
                    (
                        'filter[from]',
                        filter_from.strftime(
                            self.api_client.configuration.date_format
                        )
                    )
                )
            else:
                _query_params.append(('filter[from]', filter_from))
            
        if filter_to is not None:
            if isinstance(filter_to, date):
                _query_params.append(
                    (
                        'filter[to]',
                        filter_to.strftime(
                            self.api_client.configuration.date_format
                        )
                    )
                )
            else:
                _query_params.append(('filter[to]', filter_to))
            
        if filter_ids is not None:
            
            _query_params.append(('filter[ids]', filter_ids))
            
        if filter_status is not None:
            
            _query_params.append(('filter[status]', filter_status.value))
            
        if filter_channel is not None:
            
            _query_params.append(('filter[channel]', filter_channel.value))
            
        if filter_recipient is not None:
            
            _query_params.append(('filter[recipient]', filter_recipient))
            
        if filter_country_code is not None:
            
            _query_params.append(('filter[country_code]', filter_country_code))
            
        if way is not None:
            
            _query_params.append(('way', way.value))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/2fa/authentications',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def resend_otp(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResendOtp200Response:
        """Resend the one-time code

        sed to resend the one-time password to the recipient: a new one-time password is generated and sent in the message, and the previous one becomes invalid. When resending, already saved data is used to generate the OTP from the request [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp).  *This API call is available only if the current authentication is not completed before its expiration date (the authentication validity period is specified in each TwoFA API response).*

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._resend_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResendOtp200Response",
            '404': "ResendOtp404Response",
            '422': "ResendOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def resend_otp_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResendOtp200Response]:
        """Resend the one-time code

        sed to resend the one-time password to the recipient: a new one-time password is generated and sent in the message, and the previous one becomes invalid. When resending, already saved data is used to generate the OTP from the request [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp).  *This API call is available only if the current authentication is not completed before its expiration date (the authentication validity period is specified in each TwoFA API response).*

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._resend_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResendOtp200Response",
            '404': "ResendOtp404Response",
            '422': "ResendOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def resend_otp_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Resend the one-time code

        sed to resend the one-time password to the recipient: a new one-time password is generated and sent in the message, and the previous one becomes invalid. When resending, already saved data is used to generate the OTP from the request [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp).  *This API call is available only if the current authentication is not completed before its expiration date (the authentication validity period is specified in each TwoFA API response).*

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._resend_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResendOtp200Response",
            '404': "ResendOtp404Response",
            '422': "ResendOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _resend_otp_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/2fa/authentications/otp/{id}/resend',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def send_otp(
        self,
        send_otp_request: SendOtpRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SendOtp201Response:
        """Send One-time password

        This API call is used to generate and send a one-time password to a user in an SMS or Viber message. **Please note:** authentication of recipients who are in the SMS or Viber stop list in your contact book is not possible using the corresponding method. (That is, if the recipient is in the SMS stop list, then when requesting authentication using the SMS method, the one-time password will not be sent, and you will receive an error in response).

        :param send_otp_request: (required)
        :type send_otp_request: SendOtpRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_otp_serialize(
            send_otp_request=send_otp_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "SendOtp201Response",
            '422': "SendOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def send_otp_with_http_info(
        self,
        send_otp_request: SendOtpRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SendOtp201Response]:
        """Send One-time password

        This API call is used to generate and send a one-time password to a user in an SMS or Viber message. **Please note:** authentication of recipients who are in the SMS or Viber stop list in your contact book is not possible using the corresponding method. (That is, if the recipient is in the SMS stop list, then when requesting authentication using the SMS method, the one-time password will not be sent, and you will receive an error in response).

        :param send_otp_request: (required)
        :type send_otp_request: SendOtpRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_otp_serialize(
            send_otp_request=send_otp_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "SendOtp201Response",
            '422': "SendOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def send_otp_without_preload_content(
        self,
        send_otp_request: SendOtpRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Send One-time password

        This API call is used to generate and send a one-time password to a user in an SMS or Viber message. **Please note:** authentication of recipients who are in the SMS or Viber stop list in your contact book is not possible using the corresponding method. (That is, if the recipient is in the SMS stop list, then when requesting authentication using the SMS method, the one-time password will not be sent, and you will receive an error in response).

        :param send_otp_request: (required)
        :type send_otp_request: SendOtpRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_otp_serialize(
            send_otp_request=send_otp_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "SendOtp201Response",
            '422': "SendOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _send_otp_serialize(
        self,
        send_otp_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if send_otp_request is not None:
            _body_params = send_otp_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/2fa/authentications/otp',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def status_otp(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StatusOtp200Response:
        """Check authentication status

        Use to get information about the current authentication status by specifying its identifier.

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._status_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StatusOtp200Response",
            '404': "StatusOtp404Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def status_otp_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StatusOtp200Response]:
        """Check authentication status

        Use to get information about the current authentication status by specifying its identifier.

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._status_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StatusOtp200Response",
            '404': "StatusOtp404Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def status_otp_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Check authentication status

        Use to get information about the current authentication status by specifying its identifier.

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._status_otp_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StatusOtp200Response",
            '404': "StatusOtp404Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _status_otp_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/2fa/authentications/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def verify_otp(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        verify_otp_request: VerifyOtpRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VerifyOtp200Response:
        """Check one-time Code

        The API call is used to verify that the one-time password you received from the user matches the one sent by BSG

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param verify_otp_request: (required)
        :type verify_otp_request: VerifyOtpRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._verify_otp_serialize(
            id=id,
            verify_otp_request=verify_otp_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VerifyOtp200Response",
            '404': "VerifyOtp404Response",
            '422': "VerifyOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def verify_otp_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        verify_otp_request: VerifyOtpRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VerifyOtp200Response]:
        """Check one-time Code

        The API call is used to verify that the one-time password you received from the user matches the one sent by BSG

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param verify_otp_request: (required)
        :type verify_otp_request: VerifyOtpRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._verify_otp_serialize(
            id=id,
            verify_otp_request=verify_otp_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VerifyOtp200Response",
            '404': "VerifyOtp404Response",
            '422': "VerifyOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def verify_otp_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters.")],
        verify_otp_request: VerifyOtpRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Check one-time Code

        The API call is used to verify that the one-time password you received from the user matches the one sent by BSG

        :param id: Authentication ID received in response to [POST /api/2fa/authentications/otp](#tag/TwoFA/operation/send_otp) The maximum length is 36 characters. (required)
        :type id: str
        :param verify_otp_request: (required)
        :type verify_otp_request: VerifyOtpRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._verify_otp_serialize(
            id=id,
            verify_otp_request=verify_otp_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VerifyOtp200Response",
            '404': "VerifyOtp404Response",
            '422': "VerifyOtp422Response",
            '429': "TooManyRequestsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _verify_otp_serialize(
        self,
        id,
        verify_otp_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if verify_otp_request is not None:
            _body_params = verify_otp_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ExternalAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/2fa/authentications/otp/{id}/verify',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SuggestionLink(BaseModel):
    """
    Redirect user to url link when click the button
    """ # noqa: E501
    type: StrictStr = Field(description="Suggestion type")
    text: Annotated[str, Field(strict=True, max_length=25)] = Field(description="text of the button")
    url: Annotated[str, Field(strict=True, max_length=1000)] = Field(description="A link to go through a click on the button. The link should start with http/https.  If you need to add a button to unsubscribe the user from the mailing list, you can specify a link in the format http://nosms.cc/XXXX – the Platform will generate an Unsubscribe link for this action when sending the message. When the user clicks on the unsubscribe button, the user’s number will be added to the RCS email stop list.")
    postback_data: Optional[Annotated[str, Field(strict=True, max_length=25)]] = Field(default=None, description="Extra data to send on callback_url when user click on the button")
    __properties: ClassVar[List[str]] = ["type", "text", "url", "postback_data"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['link']):
            raise ValueError("must be one of enum values ('link')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SuggestionLink from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SuggestionLink from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "text": obj.get("text"),
            "url": obj.get("url"),
            "postback_data": obj.get("postback_data")
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreateJobParams(BaseModel):
    """
    CreateJobParams
    """ # noqa: E501
    type: StrictStr = Field(description="Job creation type")
    time_in_from: datetime = Field(description="Datetime when messages were received on the platform")
    time_in_to: datetime = Field(description="Datetime when messages were received on the platform")
    time_sent_from: Optional[datetime] = Field(default=None, description="Time of sending messages from the platform “from”")
    time_sent_to: Optional[datetime] = Field(default=None, description="Time of sending messages from the platform “to”")
    phones: Optional[List[StrictInt]] = Field(default=None, description="phone list")
    sender: Optional[StrictStr] = Field(default=None, description="Source from where the message came to the platform")
    source: Optional[StrictStr] = Field(default=None, description="Source from where the message came to the platform")
    country: Optional[StrictStr] = Field(default=None, description="The name of the country for search")
    operator_id: Optional[StrictStr] = Field(default=None, description="Indication of the country operator")
    status: Optional[StrictStr] = Field(default=None, description="The status of the messages to display")
    sl_clicks: Optional[StrictStr] = Field(default=None, description="The field is available only to the clients who have enabled Short URL service")
    sl_clicks_comp: Optional[StrictStr] = Field(default=None, description="Comparison operator with the clicks count value")
    sl_clicks_count: Optional[StrictStr] = Field(default=None, description="Comparison operator with the clicks count value")
    __properties: ClassVar[List[str]] = ["type", "time_in_from", "time_in_to", "time_sent_from", "time_sent_to", "phones", "sender", "source", "country", "operator_id", "status", "sl_clicks", "sl_clicks_comp", "sl_clicks_count"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['params']):
            raise ValueError("must be one of enum values ('params')")
        return value

    @field_validator('sender')
    def sender_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['api', 'web', 'smpp', 'xml', 'http', 'json']):
            raise ValueError("must be one of enum values ('api', 'web', 'smpp', 'xml', 'http', 'json')")
        return value

    @field_validator('source')
    def source_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['api', 'web', 'smpp', 'xml', 'http', 'json']):
            raise ValueError("must be one of enum values ('api', 'web', 'smpp', 'xml', 'http', 'json')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Delivered', 'Rejected', 'Scheduled', 'Moderation', 'Accepted', 'Sending', 'Sent', 'Expired', 'Failed', 'Undelivered', 'Unknown']):
            raise ValueError("must be one of enum values ('Delivered', 'Rejected', 'Scheduled', 'Moderation', 'Accepted', 'Sending', 'Sent', 'Expired', 'Failed', 'Undelivered', 'Unknown')")
        return value

    @field_validator('sl_clicks_comp')
    def sl_clicks_comp_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['=', '>', '<']):
            raise ValueError("must be one of enum values ('=', '>', '<')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateJobParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateJobParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "time_in_from": obj.get("time_in_from"),
            "time_in_to": obj.get("time_in_to"),
            "time_sent_from": obj.get("time_sent_from"),
            "time_sent_to": obj.get("time_sent_to"),
            "phones": obj.get("phones"),
            "sender": obj.get("sender"),
            "source": obj.get("source"),
            "country": obj.get("country"),
            "operator_id": obj.get("operator_id"),
            "status": obj.get("status"),
            "sl_clicks": obj.get("sl_clicks"),
            "sl_clicks_comp": obj.get("sl_clicks_comp"),
            "sl_clicks_count": obj.get("sl_clicks_count")
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SendOtp422Response(BaseModel):
    """
    SendOtp422Response
    """ # noqa: E501
    message: Optional[StrictStr] = Field(default=None, description="The given data was invalid.")
    errors: Optional[List[StrictStr]] = Field(default=None, description="It may be one of the following:  - **User channel not found**  This error can occur when the channel is specified incorrectly. Please ensure that you are using the correct channel and try again.  - **Template not found**  This error can occur when the template identifier is specified incorrectly or the specified template is not present in the system. Please ensure that you are using the correct template identifier and try again.  - **Invalid template status**  This error occurs when the provided template identifier in the request does not match the “Approved” status.  - **Insufficient funds**  Insufficient funds to send OTP. Please top up your account.  - **Exists on the stop list**  We’re unable to send message as the phone number of recipient is currently in stop list.  - **User channel inactive**  The message sending method is disabled. Please enable method in your personal account and try again.  - **This action is available for the account of your type only for your manager phone number.**  To send OTP code is not allowed in Demo account mode.   - **Authentication limit with status pending**  This error can occur when total authentication limit with status “pending” is exceeded for your account.  - **Total authentication limit**  This error can occur when total authentication limit is exceeded for your account.  - **Template is not available** This error occurs when you try to create authentication using a template that is only available in the test mode of your account. Please choose a different template. ")
    __properties: ClassVar[List[str]] = ["message", "errors"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SendOtp422Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SendOtp422Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "message": obj.get("message"),
            "errors": obj.get("errors")
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OtpTemplateCreate422Response(BaseModel):
    """
    OtpTemplateCreate422Response
    """ # noqa: E501
    message: Optional[StrictStr] = Field(default=None, description="The given data was invalid.")
    errors: Optional[List[StrictStr]] = Field(default=None, description="It may be one of the following:  - **The number of requests to create a template is limited to 10. Please wait for the manager approve before making a new request.** You can have no more than 10 templates with the current status “Requested”. If you already have 10 templates with this status, you need to delete one of them to create a new template. Additionally, if any of the existing templates transitions to the “Approved” or “Rejected” status, it also frees up space for creating a new template. - **The variable {code2fa} is required in the text** This error occurs when the message template text does not contain the required variable {code2fa} or the variable syntax is incorrect. This variable is intended for inserting the actual OTP code into the message text. - **The {code2fa} variable must occur only once in the text** This error occurs when multiple occurrences of the {code2fa} variable are found in the message template text. Please check the entire template text and remove any additional occurrences of the variable. - **This action is not available for the account of your type** Creating a message template for sending OTP codes is not allowed in Demo and Test account mode. - **User has a template with the identical name!** The template with the specified name in the parameter ‘name’ already exists. Please use names that are distinct from your existing templates. ")
    __properties: ClassVar[List[str]] = ["message", "errors"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OtpTemplateCreate422Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OtpTemplateCreate422Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "message": obj.get("message"),
            "errors": obj.get("errors")
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from bsg_api.models.otp_template_status import OtpTemplateStatus
from typing import Optional, Set
from typing_extensions import Self

class TwoFaTemplateResource(BaseModel):
    """
    TwoFaTemplateResource
    """ # noqa: E501
    template_id: Optional[StrictInt] = Field(default=None, description="Unique, automatically generated by a system identifier of the template within the TwoFA service.")
    name: Optional[StrictStr] = Field(default=None, description="Name of the template.  A string of 3 to 50 characters.")
    text: Optional[StrictStr] = Field(default=None, description="The text of the template message.")
    countries: Optional[List[StrictStr]] = Field(default=None, description="Two-letter country code(s) for which the template must apply. Sending messages with the OTP code will only be possible if the recipient’s number belongs to the country you specify for the template.")
    status: Optional[OtpTemplateStatus] = None
    updated_at: Optional[datetime] = Field(default=None, description="Date and time of the last change of the template in ISO 8601 format.")
    __properties: ClassVar[List[str]] = ["template_id", "name", "text", "countries", "status", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TwoFaTemplateResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TwoFaTemplateResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "template_id": obj.get("template_id"),
            "name": obj.get("name"),
            "text": obj.get("text"),
            "countries": obj.get("countries"),
            "status": obj.get("status"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from bsg_api.models.account_balance200_response import AccountBalance200Response
from bsg_api.models.account_tariffs200_response import AccountTariffs200Response
from bsg_api.models.alternative_channel import AlternativeChannel
from bsg_api.models.balance_schema import BalanceSchema
from bsg_api.models.campaign import Campaign
from bsg_api.models.campaign_details200_response import CampaignDetails200Response
from bsg_api.models.campaign_price200_response import CampaignPrice200Response
from bsg_api.models.campaign_price422_response import CampaignPrice422Response
from bsg_api.models.campaign_price_request import CampaignPriceRequest
from bsg_api.models.campaign_price_request_messages_item import CampaignPriceRequestMessagesItem
from bsg_api.models.campaign_response import CampaignResponse
from bsg_api.models.campaign_schema import CampaignSchema
from bsg_api.models.campaign_status import CampaignStatus
from bsg_api.models.campaign_stop200_response import CampaignStop200Response
from bsg_api.models.campaign_stop422_response import CampaignStop422Response
from bsg_api.models.cancel_otp200_response import CancelOtp200Response
from bsg_api.models.cancel_otp404_response import CancelOtp404Response
from bsg_api.models.cancel_otp422_response import CancelOtp422Response
from bsg_api.models.card import Card
from bsg_api.models.cards import Cards
from bsg_api.models.click_resource import ClickResource
from bsg_api.models.components import Components
from bsg_api.models.contact200_response import Contact200Response
from bsg_api.models.contact422_response import Contact422Response
from bsg_api.models.contact_create201_response import ContactCreate201Response
from bsg_api.models.contact_create422_response import ContactCreate422Response
from bsg_api.models.contact_field_collection_schema import ContactFieldCollectionSchema
from bsg_api.models.contact_field_create201_response import ContactFieldCreate201Response
from bsg_api.models.contact_field_create_request import ContactFieldCreateRequest
from bsg_api.models.contact_field_schema import ContactFieldSchema
from bsg_api.models.contact_field_type import ContactFieldType
from bsg_api.models.contact_field_update200_response import ContactFieldUpdate200Response
from bsg_api.models.contact_field_update_request import ContactFieldUpdateRequest
from bsg_api.models.contact_field_update_request_option_description import ContactFieldUpdateRequestOptionDescription
from bsg_api.models.contact_field_update_request_option_is_visible import ContactFieldUpdateRequestOptionIsVisible
from bsg_api.models.contact_field_update_request_option_name import ContactFieldUpdateRequestOptionName
from bsg_api.models.contact_field_value_pair import ContactFieldValuePair
from bsg_api.models.contact_group_schema import ContactGroupSchema
from bsg_api.models.contact_group_search_field import ContactGroupSearchField
from bsg_api.models.contact_group_search_schema import ContactGroupSearchSchema
from bsg_api.models.contact_list200_response import ContactList200Response
from bsg_api.models.contact_list_attach_request import ContactListAttachRequest
from bsg_api.models.contact_list_create201_response import ContactListCreate201Response
from bsg_api.models.contact_list_create422_response import ContactListCreate422Response
from bsg_api.models.contact_list_create_request import ContactListCreateRequest
from bsg_api.models.contact_list_detach_request import ContactListDetachRequest
from bsg_api.models.contact_list_search200_response import ContactListSearch200Response
from bsg_api.models.contact_list_search_criteria import ContactListSearchCriteria
from bsg_api.models.contact_list_search_meta import ContactListSearchMeta
from bsg_api.models.contact_list_update200_response import ContactListUpdate200Response
from bsg_api.models.contact_list_update422_response import ContactListUpdate422Response
from bsg_api.models.contact_list_update_request import ContactListUpdateRequest
from bsg_api.models.contact_lists200_response import ContactLists200Response
from bsg_api.models.contact_schema import ContactSchema
from bsg_api.models.contact_update200_response import ContactUpdate200Response
from bsg_api.models.contact_update422_response import ContactUpdate422Response
from bsg_api.models.contact_update_request import ContactUpdateRequest
from bsg_api.models.contacts200_response import Contacts200Response
from bsg_api.models.contacts_search200_response import ContactsSearch200Response
from bsg_api.models.contacts_search_criteria import ContactsSearchCriteria
from bsg_api.models.contacts_search_meta import ContactsSearchMeta
from bsg_api.models.core_price_schema import CorePriceSchema
from bsg_api.models.country_item import CountryItem
from bsg_api.models.create_job_message import CreateJobMessage
from bsg_api.models.create_job_params import CreateJobParams
from bsg_api.models.currency_item import CurrencyItem
from bsg_api.models.detail_campaign_schema import DetailCampaignSchema
from bsg_api.models.detail_campaign_schema_alternative_channels import DetailCampaignSchemaAlternativeChannels
from bsg_api.models.detail_campaign_schema_alternative_channels_sms import DetailCampaignSchemaAlternativeChannelsSms
from bsg_api.models.detail_campaign_schema_alternative_channels_statistics import DetailCampaignSchemaAlternativeChannelsStatistics
from bsg_api.models.domain_store_request import DomainStoreRequest
from bsg_api.models.domain_update_request import DomainUpdateRequest
from bsg_api.models.email_response import EmailResponse
from bsg_api.models.get_internal2fa_authentications_full_price200_response import GetInternal2faAuthenticationsFullPrice200Response
from bsg_api.models.get_internal_core_prices200_response import GetInternalCorePrices200Response
from bsg_api.models.get_internal_core_prices_by_country_code200_response import GetInternalCorePricesByCountryCode200Response
from bsg_api.models.get_internal_countries200_response import GetInternalCountries200Response
from bsg_api.models.get_internal_currencies200_response import GetInternalCurrencies200Response
from bsg_api.models.get_internal_wst_prices200_response import GetInternalWstPrices200Response
from bsg_api.models.get_internal_wst_prices_by_country_code200_response import GetInternalWstPricesByCountryCode200Response
from bsg_api.models.get_messages200_response import GetMessages200Response
from bsg_api.models.groups_trait import GroupsTrait
from bsg_api.models.individual_message_data import IndividualMessageData
from bsg_api.models.inline import Inline
from bsg_api.models.language import Language
from bsg_api.models.link_store_request import LinkStoreRequest
from bsg_api.models.link_update_request import LinkUpdateRequest
from bsg_api.models.login_request import LoginRequest
from bsg_api.models.media import Media
from bsg_api.models.message_api_schema import MessageApiSchema
from bsg_api.models.message_api_schema_alternative_channels import MessageApiSchemaAlternativeChannels
from bsg_api.models.message_api_schema_alternative_channels_sms import MessageApiSchemaAlternativeChannelsSms
from bsg_api.models.message_api_schema_alternative_channels_sms_details import MessageApiSchemaAlternativeChannelsSmsDetails
from bsg_api.models.message_api_schema_alternative_channels_viber import MessageApiSchemaAlternativeChannelsViber
from bsg_api.models.message_api_schema_alternative_channels_viber_details import MessageApiSchemaAlternativeChannelsViberDetails
from bsg_api.models.message_info import MessageInfo
from bsg_api.models.message_price_object import MessagePriceObject
from bsg_api.models.message_response import MessageResponse
from bsg_api.models.message_source import MessageSource
from bsg_api.models.message_status import MessageStatus
from bsg_api.models.message_type import MessageType
from bsg_api.models.message_universal import MessageUniversal
from bsg_api.models.meta import Meta
from bsg_api.models.meta_page import MetaPage
from bsg_api.models.operator_schema import OperatorSchema
from bsg_api.models.options import Options
from bsg_api.models.otp_channel import OtpChannel
from bsg_api.models.otp_list200_response import OtpList200Response
from bsg_api.models.otp_list_response_data import OtpListResponseData
from bsg_api.models.otp_message_status import OtpMessageStatus
from bsg_api.models.otp_status import OtpStatus
from bsg_api.models.otp_template200_response import OtpTemplate200Response
from bsg_api.models.otp_template404_response import OtpTemplate404Response
from bsg_api.models.otp_template_create200_response import OtpTemplateCreate200Response
from bsg_api.models.otp_template_create422_response import OtpTemplateCreate422Response
from bsg_api.models.otp_template_create_request import OtpTemplateCreateRequest
from bsg_api.models.otp_template_delete200_response import OtpTemplateDelete200Response
from bsg_api.models.otp_template_delete404_response import OtpTemplateDelete404Response
from bsg_api.models.otp_template_delete422_response import OtpTemplateDelete422Response
from bsg_api.models.otp_template_delete_response_data import OtpTemplateDeleteResponseData
from bsg_api.models.otp_template_list200_response import OtpTemplateList200Response
from bsg_api.models.otp_template_list_response_data import OtpTemplateListResponseData
from bsg_api.models.otp_template_status import OtpTemplateStatus
from bsg_api.models.parameter import Parameter
from bsg_api.models.phone import Phone
from bsg_api.models.phones_trait import PhonesTrait
from bsg_api.models.post_contacts_fields_delete_request import PostContactsFieldsDeleteRequest
from bsg_api.models.rcs import Rcs
from bsg_api.models.rcs_click_callback import RcsClickCallback
from bsg_api.models.rcs_message import RcsMessage
from bsg_api.models.rcs_send200_response import RcsSend200Response
from bsg_api.models.rcs_send_groups200_response import RcsSendGroups200Response
from bsg_api.models.rcs_status_callback import RcsStatusCallback
from bsg_api.models.recipients import Recipients
from bsg_api.models.resend_otp200_response import ResendOtp200Response
from bsg_api.models.resend_otp404_response import ResendOtp404Response
from bsg_api.models.resend_otp422_response import ResendOtp422Response
from bsg_api.models.search_campaign_resource import SearchCampaignResource
from bsg_api.models.search_operator import SearchOperator
from bsg_api.models.send_email import SendEmail
from bsg_api.models.send_otp201_response import SendOtp201Response
from bsg_api.models.send_otp422_response import SendOtp422Response
from bsg_api.models.send_otp_request import SendOtpRequest
from bsg_api.models.send_rcs_campaign import SendRcsCampaign
from bsg_api.models.send_rcs_campaign_groups import SendRcsCampaignGroups
from bsg_api.models.send_rcs_campaign_groups_alternative_channel import SendRcsCampaignGroupsAlternativeChannel
from bsg_api.models.send_template_email import SendTemplateEmail
from bsg_api.models.send_viber_campaign import SendViberCampaign
from bsg_api.models.send_whats_app_campaign import SendWhatsAppCampaign
from bsg_api.models.send_whats_app_campaign_alternative_channel import SendWhatsAppCampaignAlternativeChannel
from bsg_api.models.sender_request_legal201_response import SenderRequestLegal201Response
from bsg_api.models.sender_request_legal_request import SenderRequestLegalRequest
from bsg_api.models.sender_request_legal_schema import SenderRequestLegalSchema
from bsg_api.models.sender_request_natural201_response import SenderRequestNatural201Response
from bsg_api.models.sender_request_natural_request import SenderRequestNaturalRequest
from bsg_api.models.sender_request_natural_schema import SenderRequestNaturalSchema
from bsg_api.models.sender_request_schema import SenderRequestSchema
from bsg_api.models.sender_request_status import SenderRequestStatus
from bsg_api.models.sender_request_type import SenderRequestType
from bsg_api.models.sender_requests200_response import SenderRequests200Response
from bsg_api.models.sender_schema import SenderSchema
from bsg_api.models.senders200_response import Senders200Response
from bsg_api.models.short_domain_not_found import ShortDomainNotFound
from bsg_api.models.short_domain_slug_type import ShortDomainSlugType
from bsg_api.models.short_link import ShortLink
from bsg_api.models.short_link_status import ShortLinkStatus
from bsg_api.models.short_url_domain_list_schema import ShortUrlDomainListSchema
from bsg_api.models.short_url_domain_schema import ShortUrlDomainSchema
from bsg_api.models.short_url_link_schema import ShortUrlLinkSchema
from bsg_api.models.short_urls_clicks200_response import ShortUrlsClicks200Response
from bsg_api.models.short_urls_domain200_response import ShortUrlsDomain200Response
from bsg_api.models.short_urls_domain_create201_response import ShortUrlsDomainCreate201Response
from bsg_api.models.short_urls_domain_create422_response import ShortUrlsDomainCreate422Response
from bsg_api.models.short_urls_domain_update200_response import ShortUrlsDomainUpdate200Response
from bsg_api.models.short_urls_domains200_response import ShortUrlsDomains200Response
from bsg_api.models.short_urls_link200_response import ShortUrlsLink200Response
from bsg_api.models.short_urls_link404_response import ShortUrlsLink404Response
from bsg_api.models.short_urls_link_create201_response import ShortUrlsLinkCreate201Response
from bsg_api.models.short_urls_link_delete422_response import ShortUrlsLinkDelete422Response
from bsg_api.models.short_urls_link_statistic_data import ShortUrlsLinkStatisticData
from bsg_api.models.short_urls_link_update200_response import ShortUrlsLinkUpdate200Response
from bsg_api.models.short_urls_link_update422_response import ShortUrlsLinkUpdate422Response
from bsg_api.models.short_urls_links200_response import ShortUrlsLinks200Response
from bsg_api.models.sms import Sms
from bsg_api.models.sms_alt_channel import SmsAltChannel
from bsg_api.models.sms_campaign_response import SmsCampaignResponse
from bsg_api.models.sms_send_groups_request import SmsSendGroupsRequest
from bsg_api.models.sms_send_individual_request import SmsSendIndividualRequest
from bsg_api.models.sms_send_request import SmsSendRequest
from bsg_api.models.sms_send_request_phones_item import SmsSendRequestPhonesItem
from bsg_api.models.sort_way import SortWay
from bsg_api.models.stat_jobs_create200_response import StatJobsCreate200Response
from bsg_api.models.stat_jobs_create_request import StatJobsCreateRequest
from bsg_api.models.stat_jobs_delete200_response import StatJobsDelete200Response
from bsg_api.models.statistics_data import StatisticsData
from bsg_api.models.statistics_short import StatisticsShort
from bsg_api.models.status_otp200_response import StatusOtp200Response
from bsg_api.models.status_otp404_response import StatusOtp404Response
from bsg_api.models.stop_list_collection import StopListCollection
from bsg_api.models.stop_list_paginate_schema import StopListPaginateSchema
from bsg_api.models.stoplist_add200_response import StoplistAdd200Response
from bsg_api.models.stoplist_add_request import StoplistAddRequest
from bsg_api.models.stoplist_items200_response import StoplistItems200Response
from bsg_api.models.stoplist_remove_request import StoplistRemoveRequest
from bsg_api.models.stoplist_search200_response import StoplistSearch200Response
from bsg_api.models.stoplist_search_criteria import StoplistSearchCriteria
from bsg_api.models.stoplist_search_field import StoplistSearchField
from bsg_api.models.stoplist_search_meta import StoplistSearchMeta
from bsg_api.models.store_contact import StoreContact
from bsg_api.models.suggestion import Suggestion
from bsg_api.models.suggestion_call import SuggestionCall
from bsg_api.models.suggestion_link import SuggestionLink
from bsg_api.models.tariff_schema import TariffSchema
from bsg_api.models.telegram import Telegram
from bsg_api.models.template import Template
from bsg_api.models.text import Text
from bsg_api.models.token_schema import TokenSchema
from bsg_api.models.too_many_requests_response import TooManyRequestsResponse
from bsg_api.models.two_fa_template_resource import TwoFaTemplateResource
from bsg_api.models.two_factor_authentication_messages_resource import TwoFactorAuthenticationMessagesResource
from bsg_api.models.two_factor_authentication_schema import TwoFactorAuthenticationSchema
from bsg_api.models.two_factor_message_resource import TwoFactorMessageResource
from bsg_api.models.verify_otp200_response import VerifyOtp200Response
from bsg_api.models.verify_otp404_response import VerifyOtp404Response
from bsg_api.models.verify_otp422_response import VerifyOtp422Response
from bsg_api.models.verify_otp_request import VerifyOtpRequest
from bsg_api.models.viber import Viber
from bsg_api.models.viber_campaign_response import ViberCampaignResponse
from bsg_api.models.voice import Voice
from bsg_api.models.whats_app_message import WhatsAppMessage
from bsg_api.models.whats_app_message_alternative_channel import WhatsAppMessageAlternativeChannel
from bsg_api.models.whats_app_message_template import WhatsAppMessageTemplate
from bsg_api.models.wst_price_schema import WstPriceSchema



# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from bsg_api.models.short_link import ShortLink
from typing import Optional, Set
from typing_extensions import Self

class SmsSendGroupsRequest(BaseModel):
    """
    SmsSendGroupsRequest
    """ # noqa: E501
    groups: Optional[Annotated[List[StrictInt], Field(min_length=1)]] = Field(default=None, description="one or several contact list id to send messages. id of the lists can be obtained: using the Get [lists API](#tag/Contact-List) in your account [Contact Book → Lists](https://app.bsg.world/addressbook/lists)")
    sender: StrictStr = Field(description="Sender’s name: from 3 to 11 characters for the sender’s alphanumeric name (Latin letters, symbols, numbers, spaces); 3 to 15 characters for the sender’s numeric name. To setup senders visit the [account](https://app.bsg.world/sms/senders)")
    text: Annotated[str, Field(strict=True, max_length=765)] = Field(description="SMS text, max length is 765 chars for GSM 7-bit encoding (Latin), and 355 for UCS-2")
    tariff_code: Optional[StrictInt] = Field(default=None, description="Tariff code null by default. Your can pass specified one if you have several. For more information please visit the [account prices](https://app.bsg.world/prices/sms)")
    validity: Optional[Annotated[int, Field(le=72, strict=True, ge=1)]] = Field(default=72, description="validity time in hours. The default is 72 hours. Integer from 1 to 72")
    start_at: Optional[datetime] = Field(default=None, description="Start sending the messages at")
    short_links: Optional[List[ShortLink]] = None
    transliterate: Optional[StrictBool] = Field(default=False, description="apply transliteration to sms text if it necessary")
    callback_url: Optional[Any] = Field(default=None, description="Link to get the delivery status of messages. If this parameter is specified in the method, it will take precedence over the value specified in the “Callback URL” field in the Personal Area.")
    __properties: ClassVar[List[str]] = ["groups", "sender", "text", "tariff_code", "validity", "start_at", "short_links", "transliterate", "callback_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SmsSendGroupsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in short_links (list)
        _items = []
        if self.short_links:
            for _item_short_links in self.short_links:
                if _item_short_links:
                    _items.append(_item_short_links.to_dict())
            _dict['short_links'] = _items
        # set to None if callback_url (nullable) is None
        # and model_fields_set contains the field
        if self.callback_url is None and "callback_url" in self.model_fields_set:
            _dict['callback_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SmsSendGroupsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "groups": obj.get("groups"),
            "sender": obj.get("sender"),
            "text": obj.get("text"),
            "tariff_code": obj.get("tariff_code"),
            "validity": obj.get("validity") if obj.get("validity") is not None else 72,
            "start_at": obj.get("start_at"),
            "short_links": [ShortLink.from_dict(_item) for _item in obj["short_links"]] if obj.get("short_links") is not None else None,
            "transliterate": obj.get("transliterate") if obj.get("transliterate") is not None else False,
            "callback_url": obj.get("callback_url")
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from bsg_api.models.media import Media
from bsg_api.models.suggestion import Suggestion
from typing import Optional, Set
from typing_extensions import Self

class Card(BaseModel):
    """
    Either \"media\" or \"text\" is required.
    """ # noqa: E501
    title: Optional[Annotated[str, Field(strict=True, max_length=200)]] = Field(default=None, description="Message title")
    text: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=1000)]] = Field(default=None, description="It is specified only for the “text” message type. RCS message text is up to 1000 characters. Can contain emojis (character count for emojis according to UTF-16 code points. Simple emojis take 2 code points, complex emojis take 4, Cyrillic emojis take 1). If the message contains a link in the format http://nosms.cc/XXXX, the System will generate an Unsubscribe link while sending the message  **Please note:** If the message contains a media object, the text parameter is optional and can be omitted")
    media: Optional[Media] = None
    suggestions: Optional[Annotated[List[Suggestion], Field(max_length=4)]] = Field(default=None, description="An array of objects containing information about nested buttons. Only up to 2 buttons can be added to a card.")
    __properties: ClassVar[List[str]] = ["title", "text", "media", "suggestions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Card from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of media
        if self.media:
            _dict['media'] = self.media.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in suggestions (list)
        _items = []
        if self.suggestions:
            for _item_suggestions in self.suggestions:
                if _item_suggestions:
                    _items.append(_item_suggestions.to_dict())
            _dict['suggestions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Card from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "text": obj.get("text"),
            "media": Media.from_dict(obj["media"]) if obj.get("media") is not None else None,
            "suggestions": [Suggestion.from_dict(_item) for _item in obj["suggestions"]] if obj.get("suggestions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    One-API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MessageSource(str, Enum):
    """
    The source how message was sent by  - rest - by this api - web - by web interface of [personal account](https://app.bsg.world) - smpp - by smpp connection - 2fa - sent by 2fa - voicebot - sent by voicebot - twoway - two way sms by interface - twoway_api - two way sms by api - xml - service messages     
    """

    """
    allowed enum values
    """
    WEB = 'web'
    REST = 'rest'
    SMPP = 'smpp'
    XML = 'xml'
    TWOWAY = 'twoway'
    TWOWAY_API = 'twoway_api'
    ENUM_2FA = '2fa'
    VOICEBOT = 'voicebot'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MessageSource from a JSON string"""
        return cls(json.loads(json_str))


